# Generated by roxygen2: do not edit by hand

export(construct_adj_mat)
export(data_existing)
export(data_simple_1pl)
export(edge_weight_exponential)
export(edge_weight_inverse)
export(edge_weight_linear)
export(edge_weight_negative_log)
export(edge_weight_power)
export(meow)
export(meow_administered)
export(meow_long)
export(select_max_dist)
export(select_max_dist_enhanced)
export(select_max_info)
export(select_random)
export(select_restrict_rate)
export(select_sequential)
export(update_maths_garden)
export(update_prowise_learn)
export(update_theta_mle)
