                                 ━━━━━━
                                  MEOW
                                 ━━━━━━


[file:https://melpa.org/packages/meow-badge.svg]
[file:https://stable.melpa.org/packages/meow-badge.svg]
[https://github.com/meow-edit/meow/actions/workflows/action.yml/badge.svg]

<file:meow.svg>


[file:https://melpa.org/packages/meow-badge.svg]
<https://melpa.org/#/meow>

[file:https://stable.melpa.org/packages/meow-badge.svg]
<https://stable.melpa.org/#/meow>

[https://github.com/meow-edit/meow/actions/workflows/action.yml/badge.svg]
<https://github.com/meow-edit/meow/actions/workflows/action.yml>


1 Introduction
══════════════

        Less is more

  Meow is yet another modal editing mode for Emacs.

  Meow aims to blend modal editing into Emacs with minimal interference
  with its original key-bindings, avoiding most of the hassle introduced
  by key-binding conflicts. This leads to lower necessary configuration
  and better integration. More is achieved with fewer commands to
  remember.

  Key features compared to existing solutions:

  • Minimal configuration – build your own modal editing system
  • No third-party dependencies ([try it without touching your
    configuration])
  • Doesn't occupy too many keys
    • Much easier to remember for people trying modal editing
    • More keys available for your own key-bindings
    • Most of the time, you don't even need to hold shift!
  • Lightning fast (unlike Evil)
  • Minimizes modifier usage (e.g. `SPC x f' for `C-x C-f') inspired by
    [god-mode]
  • Better workflow for [kmacro] application at multiple locations
  • Interactive selection manipulation and expansion inspired by avy
  • Selection as top-tier object, and keybindings built around selection
  • Compatible with the vanilla Emacs keymap (or any other keymap from
    any package)
  • Effortless uniform keymaps across modes
  • Key-binding conflict handling made easy


[try it without touching your configuration] <file:GET_STARTED.org>

[god-mode] <https://github.com/emacsorphanage/god-mode>

[kmacro]
<https://www.gnu.org/software/emacs/manual/html_node/emacs/Keyboard-Macros.html>


2 Community
═══════════

  Please feel free to ask questions and share ideas at

  • [Github Discussion]

  • [Meow XMPP Channel]


[Github Discussion] <https://github.com/meow-edit/meow/discussions>

[Meow XMPP Channel] <https://xmpp.link/#meow@chat.disroot.org?join>


3 Documents
═══════════

  [Get started] - Installation and configuration

  [Tutorial] - Learn Meow in 15 minutes

  [FAQ] - Frequently Asked Questions

  [Commands] - Documentation for commands

  [Customizations] - Helper functions and variables

  [Explanation] - Ideas and concepts behind Meow

  [Changelog] - Changes, releases, and news


[Get started] <file:GET_STARTED.org>

[Tutorial] <file:TUTORIAL.org>

[FAQ] <file:FAQ.org>

[Commands] <file:COMMANDS.org>

[Customizations] <file:CUSTOMIZATIONS.org>

[Explanation] <file:EXPLANATION.org>

[Changelog] <file:CHANGELOG.md>


4 License
═════════

  Licensed under GPLv3.
